all.Litms<-function(){
     cat("\n")
     note_for_Lit_input()  
     cat("\n")
     note_for_close_window()
     LitMSpar<-data.frame(subject=c(1,2),age=c(0),f=c(0),bw=c(0),Scr=c(0),D=c(0),tau=c(0),c=c(0))
     LitMSpar<-edit(LitMSpar)
##     LitMSpar<-ymscheck(LitMSpar)
     cat("\n")
     Lit.ms(length(LitMSpar$subject),LitMSpar$c,LitMSpar$tau,LitMSpar$age,LitMSpar$D,LitMSpar$Scr,LitMSpar$bw,LitMSpar$f)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Lit_output()
     show(samplesStats("*"))
     cat("\n")
     C<-Litcpr(LitMSpar$D,LitMSpar$tau)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mEq/L)")
     show(coutput)  
     cat("\n")   
     cal.again()
}